@@ -110,7 +110,7 @@ TEST_CASE("ut_dssp")
 	std::string line_t, line_r;
 	CHECK((std::getline(test, line_t) and std::getline(reference, line_r)));
 
-	char kHeaderLineStart[] = "==== Secondary Structure Definition by the program DSSP, NKI version 4.5.0                         ====";
+	char kHeaderLineStart[] = "==== Secondary Structure Definition by the program DSSP, NKI version 4.5.4                         ====";
 	memcpy(kHeaderLineStart + 69, kVersionNumber, strlen(kVersionNumber));
 
 	CHECK(line_t.compare(0, std::strlen(kHeaderLineStart), kHeaderLineStart) == 0);
@@ -126,9 +126,14 @@ TEST_CASE("ut_dssp")
 			break;
 
 		if (line_t != line_r)
+		{
+			if (cif::starts_with(line_t, "REFERENCE ") and cif::starts_with(line_r, "REFERENCE "))
+				continue;
+
 			std::cerr << line_nr << std::endl
 					  << line_t << std::endl
 					  << line_r << std::endl;
+		}
 
 		if (line_t != line_r)
 		{
